class ResizedImage
	@@sizes			= %w(420 600 1200) # Width in pixels of required versions
	@@dest			= "assets/static" # Where to save rendered images

	def initialize(path)
		@path		= path
		@config = Jekyll.sites.first.config['resized_image'] ||= {}

		@source		= @config['source']
		@dry		= @config.fetch('dry', false)
		@verbose	= @config.fetch('verbose', false)

		@versions	= versions
		validate_original if local_assets_enabled?
		generate_versions if local_assets_enabled?
	end

	def validate_original
		original = @versions.first['original']['absolute_path']
		unless File.file?(original)
			message = ""
			message << "ResizedImage.rb failed to validate the presense of: "
			message << original
			raise StandardError.new message
		end
	end

	def local_assets_enabled?
		if ENV['LOCAL_ASSETS'] == "true"
			return true
		elsif Jekyll.sites.first.config['local_assets_enabled']
			return true
		else
			return false
		end
	end

	def versions 
		result = []
		@@sizes.each do | size |
			version = {}
			version["root"] = "#{File.basename(@path, ".*")}-#{size}w"
			version["size"] = size
			version["ext"] = ".webp"
			version["filename"] = "#{version["root"]}#{version["ext"]}"
			version["absolute_path"] = "#{@@dest}/#{version["filename"]}"
			version["original"] = {
				"filename" => File.basename(@path),
				"dir" => File.dirname(@path),
				"root" => File.basename(@path, ".*"),
				"ext" => File.extname(@path),
				"absolute_path" => "#{@source}/#{@path}",
			}
			result << version
		end
		return result
	end

	def generate_versions
		@versions.each do | version |
			message = "Resizing #{version['original']['filename']} "
			message << "to #{version['size']}w... "

			if File.file?(version["absolute_path"])
				message << "Skipping (already exists)."
				puts message if @verbose
			else
				cmd = ""
				cmd << "convert "
				cmd << version["original"]["absolute_path"]
				cmd << " -resize "
				cmd << version["size"].to_s
				cmd << " "
				cmd << version["absolute_path"]

				message << "(#{version["absolute_path"]})"
				puts message if @verbose

				if @dry
					puts "*** DRY RUN ***"
					puts cmd
				else
					system cmd
				end
			end
		end
	end

end
